@@ -125,7 +125,7 @@ const QwtPlot *QwtPlotPanner::plot() const
    \param dx Pixel offset in x direction
    \param dy Pixel offset in y direction
 
-   \sa QwtPanner::panned
+   \sa QwtPanner::panned()
 */
 void QwtPlotPanner::moveCanvas(int dx, int dy)
 {
